//
//  KMAdvancedPush.h
//  Koupon
//
//  Created by Brian Reinhart on 4/15/14.
//  Copyright (c) 2014 Brian Reinhart. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
#import "TransitionDelegate.h"
@protocol KMAdvancedPushDelegate <NSObject>
@optional
/** Called when the Advanced Push window is opened inside the app.
 */
- (void) pushViewOpened;
/** Called when the Advanced Push window is closed.
 */
- (void) pushViewClosed;
/** Called when an error occured while trying to open the Advanced Push window.
 @param error NSError
 */
- (void) pushViewFailedToOpen: (NSError*) error;
@end


@interface KMAdvancedPush : NSObject {
    BOOL _displayPushOnActive;
    NSDictionary *_storedUserDictionary;
}
@property (nonatomic, weak) id <KMAdvancedPushDelegate> delegate;
@property (nonatomic, strong) UIViewController* parentViewController;
@property (nonatomic, strong) TransitionDelegate *transitionController;

/** Singleton accessor.  Use this static method for getting the shared instance of the KouponGimbalManager class.
 @return KouponGimbalManager
 */
+ (KMAdvancedPush *)shared;
/** Handle the Advanced Push with the given dictionary.
 The dictionary is either the userInfo dictionary from didReceiveRemotePushNotification or the launchOptions dictionary from application:didFinishLaunchingWithOptions.
 
 This method uses the parentViewController property.  If no parentViewController property is set, it will return an error to the pushViewFailedToOpen delegate selector.
 
 @param pushDictionary NSDictionary
 */
- (void) handleAdvancedPush: (NSDictionary*) pushDictionary;
/** Handle the Advanced Push with the given dictionary and the given view Controller.
 The dictionary is either the userInfo dictionary from didReceiveRemotePushNotification or the launchOptions dictionary from application:didFinishLaunchingWithOptions.
 
 The given viewController overrides the parentViewController property.
 @param pushDictionary NSDictionary
 @param viewController UIViewController
 */
- (void) handleAdvancedPush: (NSDictionary*) pushDictionary WithViewController: (UIViewController*) viewController;
@end
